==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Palautetaan järjestelmä takaisin, odota...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Palautus epäonnistui.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Päivitys epäonnistui.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Päivitykset epäonnistuivat: toiminta keskeytettiin.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Päivitykset epäonnistuivat: DPKG-virhe.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Päivitykset epäonnistuivat: levytila ei riitä.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Haluatko varmasti palata takaisin %1 varmuuskopiosta %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Peru ja käynnistä</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.35.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Palautetaan järjestelmä takaisin, odota...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Palautus epäonnistui.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Päivitys epäonnistui.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Päivitykset epäonnistuivat: toiminta keskeytettiin.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Päivitykset epäonnistuivat: DPKG-virhe.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Päivitykset epäonnistuivat: levytila ei riitä.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Haluatko varmasti palata takaisin %1 varmuuskopiosta %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Peru ja käynnistä</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
</TS>
